# Parameter array for R program Digital_Cyclist to switch parameter values during a simulation run
# developed by J.H.G.M. van Beek - May 2008 and December 2010, updated December 2013

# parameter array with global parameters
    pa_default <- c(
          # here parameters are named and given a default value
          # the values below come from p. 51 of the Stolwijk report (1971)
          CSW = 320.,
          SSW = 29.0,
          PSW = 0.,
          BULL = 10.0,
          # the following values come from p. 54 of the mentioned report
          CDIL = 117.0,
          SDIL = 7.5,
          PDIL = 0.,
          # the following values come from p. 58 of the mentioned report
          CCHIL = 0.0,
          SCHIL = 0.0,
          PCHIL = 21.0,
          # the following values are inferred from p. 58, the expression for STRIC at the bottom, in conjunction
          # with p. 41
          CCON=5.0,
          SCON=5.0,
          PCON=0.0,
          #
          T_air=20.,
          # V, air velocity (m/s) across body, used for convective transport in Stolwijk model
          # for the moment taken to blow from ahead and also determining wind contribution to air resistance
          V = 0.1,
          # relative humidity
          RH= 0.3,
          BASAL_METABOLIC_RATE = 74.4,
          WORK=74.4,

          # up till this point parameters come from Stolwijk equations and pertain to energy usage, blood flow,
          # heat transport, sweating, temperature control

          # energy supply from Olds model.
          # brainpush: exertion level the athlete reaches under voluntary control given fatigue and
          # exhaustion which (s)he experiences, given as a fraction of VO2max
          brainpush = 0.752, # from Olds (1995) paper
          # DeltaMechEff, Delta Efficiency as in Coyle's paper - here the default value is given from Stolwijk
          DeltaMechEff = 0.22,
          # VO2max in litre/min, STPD
          VO2max = 5.143,
          # VO2init, initial oxygen consumption, before start in litre/min, STPD
          VO2init = 0.681,
          # Mb = mass bicycle plus clothing (kg)
          Mb = 7.3, # minimum weight according to UCI rules (6.8 kg) + weight clothing (0.5 kg)
          # Ma, mass athlete (kg)
          # the heat capacities above can be made to depend on the body size of the athlete
          Ma = 75.29,
          # Ht, height athlete (cm)
          Ht = 179.3,

          # bicycle resistance parameters
          # rolling resistance parameter, Crr
          Crr = 0.0457,
          # air resistance reduction gain relative to assumed Cair, Olds (1993), di Prampero (1979)
          RedAir = 1.0,
          # slope of the road in meter/meter, i.e. rise/run
          S = 0.,
          # AreaRatio, projected frontal area/total body area, important to determine air resistance
          AreaRatio = 0.25,
          # PB, barometric pressure (mmHg) taken at sea level
          PB = 760,
          # if reduction of barometric pressure should be calculated, set pa["VO2_red_by_alt"] = 1
          pb_red_by_alt = 1,
          # if effect of reduction by altitude of barometric pressure must be calculated set next parameter to 1
          VO2_red_by_alt = 1,
          # if reduction of air resistance by altitude must be calculated set next parameter 1
          Air_res_red_by_alt = 1,
          # acceleration due to gravity, m / sec^2
          g = 9.807
          )
