# SETTING PARAMETERS - READ CONSTANTS CONTROLLED SYSTEM
# In the following section default parameters and initial conditions are set
# The values for node 1 through 25 are given in vectors

# array of heat capacities in kcal / degree Celsius
     CC <- c(
        2.22,
        0.33,
        0.22,
        0.24,
        9.82, # with heat capacity of central blood subtracted from value Table 5 (Stolwijk), yielding value in Table 8
        16.15,
        4.25,
        1.21,
        1.41,
        3.04,
        0.58,
        0.43,
        0.14,
        0.06,
        0.09,
        0.17,
        4.24,
        9.17,
        1.43,
        1.08,
        0.23,
        0.06,
        0.13,
        0.22,
        2.25
        )

# total skin heat capacity
     CCskin_tot <- 0.
     for (i in 1:6) {
       CCskin_tot <- CCskin_tot + CC[4*i]
       }

# total body heat capacity
     CCbody_tot <- 0.
     for (i in 1:25) {
       CCbody_tot <- CCbody_tot + CC[i]
       }

# basal metabolic heat production - in kcal / hour
     QB <- c(
        12.84,
        0.10,
        0.11,
        0.08,
        45.38,
        5.00,
        2.13,
        0.40,
        0.70,
        0.95,
        0.17,
        0.13,
        0.08,
        0.20,
        0.03,
        0.05,
        2.23,
        2.86,
        0.43,
        0.32,
        0.13,
        0.02,
        0.04,
        0.07
        )

# basal evaporative heat loss in kcal / hour
     EB <- c(
        0.,
        0.,
        0.,
        0.63,
        9.00,
        0.,
        0.,
        3.25,
        0.,
        0.,
        0.,
        1.20,
        0.,
        0.,
        0.,
        0.45,
        0.,
        0.,
        0.,
        2.85,
        0.,
        0.,
        0.,
        0.62
        )

# basal effective blood flow in litre / hour
     BFB <- c(
         45.00,
         0.12,
         0.13,
         1.44,
         210.00,
         6.00,
         2.56,
         2.10,
         0.84,
         1.14,
         0.20,
         0.50,
         0.10,
         0.24,
         0.04,
         2.00,
         2.69,
         3.43,
         0.52,
         2.85,
         0.16,
         0.02,
         0.05,
         3.00
         )

# thermal conductance between compartment N and N+1 in kcal/hour/degree Celsius
     TC <- c(
        1.38,
        11.4,
        13.8,
        0.,
        1.37,
        4.75,
        19.80,
        0.,
        1.20,
        8.90,
        26.20,
        0.,
        5.50,
        9.65,
        9.90,
        0.,
        9.,
        12.4,
        64.,
        0.,
        14.0,
        17.7,
        14.1,
        0.
        )

# Surface area of skin chosen for men, not women. Unit m^2
    S <- c(
      0.1326,
      0.6804,
      0.2536,
      0.0946,
      0.5966,
      0.1299
      )

# total surface area
    SA <- 0.
    for (i in 1:6) {
       SA <- SA + S[i]
    }

# radiant heat transfer coefficient from skin, segment 1 through 6, in kcal / m^2 / hour / degree Celsius
    HR <- c(
       5.5,
       4.5,
       4.3,
       3.0,
       4.0,
       4.0
       )

# convective and conductive heat transfer coefficient from skin, segment 1 through 6, in kcal / m^2 / hour / degree Celsius
    HC <- c(
       2.75,
       2.15,
       3.0,
       3.35,
       2.75,
       3.0
       )

# vapour pressure table from 5 to 50 degrees Celsius (steps of 5 degrees), in mmHg
    P <- c(
      6.541,
      9.205,
      12.78,
      17.51,
      23.69,
      31.71,
      42.02,
      55.13,
      71.66,
      92.30
      )

# reference temperatures calculated for thermoneutral conditions in degree Celsius
    TSET <- c(
       Tbrain =      36.96,
       Thd_muscle =  35.07,
       Thd_fat =     34.81,
       Thd_skin =    34.58,
       Ttr_core =    36.89,
       Ttr_muscle =  36.28,
       Ttr_fat = 34.53,
       Ttr_skin = 33.62,
       Tarm_core = 35.53,
       Tarm_muscle = 34.12,
       Tarm_fat = 33.59,
       Tarm_skin = 33.25,
       Thand_core = 35.41,
       Thand_muscle = 35.38,
       Thand_fat = 35.30,
       Thand_skin = 35.22,
       Tleg_core = 35.81,
       Tleg_muscle = 35.30,
       Tleg_fat = 35.31,
       Tleg_skin = 34.10,
       Tfeet_core = 35.14,
       Tfeet_muscle = 35.03,
       Tfeet_fat = 35.11,
       Tfeet_skin = 35.04,
       Tblood = 36.71
       )

# sensitivity to rate of change of temperature, set to zero
     RATE <- c(
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.,
          0.
          )

# fraction of total skin receptors sending signals to central controller
    SKINR <- c(
          0.0695,
          0.4935,
          0.0686,
          0.1845,
          0.1505,
          0.0334
          )

# fraction of sweating command applicable to skin of segment I
    SKINS <- c(
          0.081,
          0.481,
          0.154,
          0.031,
          0.218,
          0.035
          )

# fraction of vasodilation command applicable to skin of segment I
    SKINV <- c(
          0.132,
          0.322,
          0.095,
          0.121,
          0.230,
          0.10
          )

# fraction of vasoconstriction command applicable to skin of segment I
    SKINC <- c(
          0.05,
          0.15,
          0.05,
          0.35,
          0.05,
          0.35
          )

# fraction of total work done by muscles in segment I. Present numbers apply to bicycle work
    WORKM <- c(
          0.,
          0.30,
          0.08,
          0.01,
          0.60,
          0.01
          )

# fraction of total shivering occuring in muscles of segment I
    CHILM <- c(
          0.02,
          0.85,
          0.05,
          0.00,
          0.07,
          0.00
          )
